@@ -4,8 +4,8 @@ Last Change Author: Paul Côté
 Last Date Changed: 2022/09/07
 """
 
-import src.laniakea_plugin_sdk.proto.plugin_pb2 as plugin_pb2
-import src.laniakea_plugin_sdk.proto.plugin_pb2_grpc as plugin_pb2_grpc
+import laniakea_plugin_sdk.proto.plugin_pb2 as plugin_pb2
+import laniakea_plugin_sdk.proto.plugin_pb2_grpc as plugin_pb2_grpc
 
 from concurrent import futures
 import grpc
@@ -47,6 +47,7 @@ class DatasourceBase(plugin_pb2_grpc.DatasourceServicer):
         if laniV < plugVConstraint:
             raise ValueError("plugin requires a different version of laniakea")
         self.laniVersion = request.version
+        return plugin_pb2.Empty()
 
 def Serve(servicer):
     health = HealthServicer()
